@@ -319,6 +319,7 @@ print("#turtle#")`);
 
 const quizString = `#platform-quiz
 import ipyquiz
+type = "normal"
 quizzes = []
 
 quizzes.append({
@@ -395,7 +396,7 @@ quizzes.append({
   ]
 })
 
-ipyquiz.QuizWidget(value=quizzes, quiz_id="__ipyquiz_quiz_id")
+ipyquiz.QuizWidget(value=quizzes, type=type quiz_id="__ipyquiz_quiz_id")
 `;
 
 const addQuizStep = function () {
